@@ -1,5 +1,5 @@
 ;;; howm-view.el --- Wiki-like note-taking tool
-;;; Copyright (C) 2002, 2003, 2004, 2005-2020
+;;; Copyright (C) 2002, 2003, 2004, 2005-2021
 ;;;   HIRAOKA Kazuyuki <khi@users.osdn.me>
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
@@ -172,6 +172,8 @@ key	binding
 \\[riffle-scroll-other-window]	Scroll contents one line
 \\[riffle-scroll-other-window-down]	Scroll contents one line
 \\[riffle-summary-to-contents]	Concatenate all contents
+\\[howm-view-summary-next-section]	Next file (Skip items in the same file)
+\\[howm-view-summary-previous-section]	Previous file (Skip items in the same file)
 \\[howm-view-filter-uniq]	Remove duplication of same file
 \\[howm-view-summary-shell-command]	Execute command in inferior shell
 
